==> fast_header-0.1.2.tar.gz: fast_header-0.1.2/fast_header/helper.py <==
from collections.abc import Callable
import re
from typing import Any, List, cast

from pydantic import BaseModel, ValidationError, WrapValidator
from pydantic.fields import FieldInfo


def invalid_to_none(v: Any, handler: Callable[[Any], Any]) -> Any:
    try:
        return handler(v)
    except ValidationError:
        return None


Invalid2None = WrapValidator(invalid_to_none)


class HeaderModel(BaseModel):

    @classmethod
    def __field_alias__(cls, info: FieldInfo) -> List[str] | str | None:
        if not info.json_schema_extra:
            return None
        if isinstance(info.json_schema_extra, Callable):
            extra = {}
            info.json_schema_extra(extra)
        else:
            extra = info.json_schema_extra
        alias = cast(List[str] | str | None, extra.get("alias"))
        return alias

    @classmethod
    def __pydantic_init_subclass__(cls, **kwargs):
        super().__init_subclass__(**kwargs)
        ret = {}
        for k, info in cls.model_fields.items():
            alias = cls.__field_alias__(info)
            if not alias:
                continue
            if isinstance(alias, List):
                for a in alias:
                    ret[a] = k
            elif isinstance(alias, str):
                ret[alias] = k
            else:
                raise ValueError("alias should be str or List[str]")
        cls.__alias_mapping__ = ret


# RegExp to match chars that must be quoted-pair in RFC 2616
QUOTE_REGEXP = re.compile(r"""([\\"])""")  # g


def qstring(text: str) -> str:
    return '"' + QUOTE_REGEXP.sub(lambda m: "\\" + m.group(1), text) + '"'

==> fast_header-0.1.3.tar.gz: fast_header-0.1.3/fast_header/helper.py <==
from collections.abc import Callable
import re
from typing import Any, List, cast

from pydantic import BaseModel, ValidationError, WrapValidator
from pydantic.fields import FieldInfo


def invalid_to_none(v: Any, handler: Callable[[Any], Any]) -> Any:
    try:
        return handler(v)
    except ValidationError:
        return None


Invalid2None = WrapValidator(invalid_to_none)


class HeaderModel(BaseModel):

    @classmethod
    def __field_alias__(cls, info: FieldInfo) -> List[str] | str | None:
        if not info.json_schema_extra:
            return None
        if isinstance(info.json_schema_extra, Callable):
            extra = {}
            info.json_schema_extra(extra)
        else:
            extra = info.json_schema_extra
        alias = cast(List[str] | str | None, extra.get("alias"))
        return alias

    @classmethod
    def __pydantic_init_subclass__(cls, **kwargs):
        super().__pydantic_init_subclass__(**kwargs)
        ret = {}
        for k, info in cls.model_fields.items():
            alias = cls.__field_alias__(info)
            if not alias:
                continue
            if isinstance(alias, List):
                for a in alias:
                    ret[a] = k
            elif isinstance(alias, str):
                ret[alias] = k
            else:
                raise ValueError("alias should be str or List[str]")
        cls.__alias_mapping__ = ret


# RegExp to match chars that must be quoted-pair in RFC 2616
QUOTE_REGEXP = re.compile(r"""([\\"])""")  # g


def qstring(text: str) -> str:
    return '"' + QUOTE_REGEXP.sub(lambda m: "\\" + m.group(1), text) + '"'
